@@ -140,6 +140,7 @@ class Command(object):
         self.bmc = bmc
         self._sdr = None
         self._oem = None
+        self._oemknown = False
         self._netchannel = None
         self._ipv6support = None
         self.certverify = None
@@ -220,9 +221,10 @@ class Command(object):
         method does an interrogation to identify the OEM.
 
         """
-        if self._oem:
+        if self._oemknown:
             return
-        self._oem = get_oem_handler(self._get_device_id(), self)
+        self._oem, self._oemknown = get_oem_handler(self._get_device_id(),
+                                                    self)
 
     def get_bootdev(self):
         """Get current boot device override information.
@@ -431,6 +433,10 @@ class Command(object):
         rsp['data'] = buffer(rsp['data'])
         return rsp
 
+    def get_diagnostic_data(self, savefile, progress=None):
+        self.oem_init()
+        return self._oem.get_diagnostic_data(savefile, progress)
+
     def get_description(self):
         """Get physical attributes for the system, e.g. for GUI use
 
@@ -757,6 +763,14 @@ class Command(object):
         self.oem_init()
         return self._oem.set_system_configuration(changeset)
 
+    def clear_system_configuration(self):
+        """Clear the Bios/UEFI configuration
+
+        This requests the system revert to factory default settings
+        """
+        self.oem_init()
+        self._oem.clear_system_configuration()
+
     def set_net_configuration(self, ipv4_address=None, ipv4_configuration=None,
                               ipv4_gateway=None, channel=None):
         """Set network configuration data.
